@@ -21,8 +21,8 @@ class GenomicInterval(Interval):
         :param data: extra data to be associated with the interval
         """
         if chromosome is not None:
-            start = GenomicPosition(chromosome, start, strand=strand)
-            stop = GenomicPosition(chromosome, stop, strand=strand)
+            start = start if isinstance(start, GenomicPosition) else GenomicPosition(chromosome, start, strand=strand)
+            stop = stop if isinstance(stop, GenomicPosition) else GenomicPosition(chromosome, stop, strand=strand)
         super().__init__(start, stop, data=data)
 
     def __str__(self):
@@ -139,7 +139,7 @@ class GenomicInterval(Interval):
     def get_sub_seq(self, sequence_set, fr=None, to=None):
         fr = self.start.position if fr is None else max(self.start.position, fr)
         to = self.stop.position if to is None else min(self.stop.position, to)
-        res = sequence_set.fetch(str(self.chromosome), fr, to)
+        res = sequence_set.fetch(str(self.chromosome), fr + 1, to)
         if self.strand == '-':
             res = reverse_complement(res)
         return res
